==> dde-shell_2.0.3.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estil de l&apos;indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mode clàssic</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mode centrat</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantén-ho visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantén-ho amagat</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Paràmetres de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Desactiva l&apos;afinació lliure</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estil de l&apos;indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mode clàssic</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mode centrat</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantén-ho visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantén-ho amagat</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Paràmetres de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Bloca l&apos;acoblador</translation>
    </message>
</context>
</TS>
